import { ViewPlugin, PluginValue, DecorationSet, EditorView, ViewUpdate } from '@codemirror/view';

/**
 * Options for the indent wrapped lines extension
 */
interface IndentWrappedLinesOptions {
    /**
     * The initial indent for the wrapped lines
     *
     * This indent is added before calculating the rest of the indent
     *
     * @example
     * // initialIndent: 4
     *
     * `this line would indent the wrapped lines
     *     by 4 times the initialIndentType
     *     and so forth`
     *
     * @default 0
     */
    initialIndent: number;
    /**
     * Determines the type of indent to use for the initial indent
     *
     * @example
     * // initialIndentType: "space"
     *
     * `this line would indent the wrapped lines
     *     by 4 spaces
     *     and so forth`
     *
     * @default "space"
     */
    initialIndentType: "space" | "tab" | "indentUnit";
}

interface Spacing {
    amountOfSpacing: number;
    containsTab: boolean;
}
declare class IndentWrappedLinesPlugin implements PluginValue {
    decorations: DecorationSet;
    private view;
    private indentUnit;
    private isChrome;
    private options;
    private initialPadding;
    constructor(view: EditorView, options: IndentWrappedLinesOptions);
    update(update: ViewUpdate): void;
    private generate;
    private appendStylesToBuilder;
    private getVisibleLines;
    getNumberOfColumns(value: string, tabSize: number): Spacing;
    private getInitialIndentValue;
}
/**
 * An extension for CodeMirror to indent wrapped lines
 * This extension also contains the extension to enable line wrapping
 *
 * @example
 * const extensions = [
 * 	indentWrappedLines(),
 * ];
 *
 * @example
 * const options = {
 * 	initialIndent: 4,
 * 	initialIndentType: "indentUnit",
 * };
 *
 * const extensions = [
 * 	indentWrappedLines(options),
 * ];
 *
 * @param options Options for the indent wrapped lines extension
 * @returns A CodeMirror extension
 */
declare function indentWrappedLines(options?: Partial<IndentWrappedLinesOptions>): ViewPlugin<IndentWrappedLinesPlugin>;

export { indentWrappedLines };
